@@ -86,10 +86,10 @@ static GtkWidget *dicePixmaps[NUMBER_OF_DICE][NUMBER_OF_PIXMAPS][GAME_TYPES];
 GSettings *settings;
 GtkWidget *window;
 GtkWidget *ScoreList;
-static GtkWidget *statusbar;
 static GtkToolItem *diceBox[NUMBER_OF_DICE];
 static GtkWidget *rollLabel;
 static GtkWidget *mbutton;
+static GtkWidget *hbar;
 static GAction *scores_action;
 static GAction *undo_action;
 static gchar *game_type_string = NULL;
@@ -184,7 +184,6 @@ CheerWinner (void)
     pos = games_scores_add_plain_score (highscores, (guint32) WinningScore);
 
     if (pos > 0) {
-      games_scores_update_score (highscores, players[winner].name);
       if (dialog) {
         gtk_window_present (GTK_WINDOW (dialog));
       } else {
@@ -565,17 +564,14 @@ say (char *fmt, ...)
 {
   va_list ap;
   char buf[200];
-  guint context_id;
 
   if (test_computer_play > 0) return;
   va_start (ap, fmt);
   g_vsnprintf (buf, 200, fmt, ap);
   va_end (ap);
 
-  context_id =
-    gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "message");
-  gtk_statusbar_pop (GTK_STATUSBAR (statusbar), context_id);
-  gtk_statusbar_push (GTK_STATUSBAR (statusbar), context_id, buf);
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (hbar), buf);
+
 }
 
 
@@ -603,7 +599,7 @@ about_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
   gtk_show_about_dialog (GTK_WINDOW (window),
 			 "name", appName,
 			 "version", VERSION,
-			 "copyright", "Copyright \xc2\xa9 1998-2008 "
+			 "copyright", "Copyright © 1998–2008 "
 			 "Free Software Foundation, Inc.",
 			 "license-type", GTK_LICENSE_GPL_2_0,
 			 "comments", _("A variation on poker with "
@@ -725,15 +721,14 @@ GyahtzeeCreateMainWindow (void)
   window = gtk_application_window_new (application);
   gtk_window_set_application (GTK_WINDOW (window), application);
   gtk_window_set_title (GTK_WINDOW (window), _(appName));
-  gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (window), TRUE);
+  gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (window), FALSE);
+  gtk_window_set_icon_name(GTK_WINDOW (window), "tali");
 
   //games_conf_add_window (GTK_WINDOW (window), NULL);
 
   g_signal_connect (G_OBJECT (window), "key_press_event",
 		    G_CALLBACK (key_press), NULL);
 
-  statusbar = gtk_statusbar_new ();
-
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries, G_N_ELEMENTS (app_entries), application);
   gtk_application_add_accelerator (application, "<Primary>z", "app.undo", NULL);
   gtk_application_add_accelerator (application, "<Primary>q", "app.quit", NULL);
@@ -758,6 +753,13 @@ GyahtzeeCreateMainWindow (void)
   update_undo_sensitivity();
   gtk_application_set_app_menu (GTK_APPLICATION (application), G_MENU_MODEL (app_menu));
 
+        /*--- Headerbar ---*/
+  hbar = gtk_header_bar_new ();
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (hbar), TRUE);
+  gtk_header_bar_set_title (GTK_HEADER_BAR (hbar), _(appName));
+  gtk_widget_show (hbar);
+  gtk_window_set_titlebar (GTK_WINDOW (window), hbar);
+
 	/*---- Content ----*/
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -766,9 +768,7 @@ GyahtzeeCreateMainWindow (void)
   gtk_container_add (GTK_CONTAINER (window), vbox);
 
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
-  gtk_widget_show (statusbar);
   /* Retreive dice pixmaps from memory or files */
   LoadDicePixmaps ();
 
